==> php74-piwigo-2.9.1.tgz: share/piwigo/language/en_UK/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2016 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Installation'] = "Installation";
$lang['Basic configuration'] = "Basic configuration";
$lang['Default gallery language'] = "Default gallery language";
$lang['Database configuration'] = "Database configuration";
$lang['Admin configuration'] = "Administration configuration";
$lang['Start Install'] = "Start installation";
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'It will be shown to visitors. It is necessary for website administration';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Connection to server successful, but the connection to the database was not possible.';
$lang['Can\'t connect to server'] = "Cannot connect to server";
$lang['Host'] = "Host";
$lang['localhost or other, supplied by your host provider'] = "localhost or other, supplied by your host provider";
$lang['User'] = "User";
$lang['user login given by your host provider'] = 'user login supplied by your host provider';
$lang['user password given by your host provider'] = 'user password supplied by your host provider';
$lang['Database name'] = "Database name";
$lang['also given by your host provider'] = 'also supplied by your hosting provider';
$lang['Database table prefix'] = "Database tables prefix";
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'database table names will be prefixed with it (enables you to manage your tables better)';
$lang['enter a login for webmaster'] = 'please enter the webmaster username';
$lang['webmaster login can\'t contain characters \' or "'] = 'the webmaster login may not contain the characters \' or "';
$lang['please enter your password again'] = "please enter your password again";
$lang['Keep it confidential, it enables you to access administration panel'] = 'Keep it confidential, it enables you to access the administration panel';
$lang['Password [confirm]'] = "Password [confirm]";
$lang['verification'] = "verification";
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Need help? Ask your question on the <a href="%s">Piwigo message board</a>.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Visitors will be able to use this email to contact the site administrator';
$lang['PHP 5 is required'] = 'PHP 5.2 is required';
$lang['It appears your webhost is currently running PHP %s.'] = "It appears your webhost is currently running PHP %s.";
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo may try to switch your configuration to PHP 5.2 by creating or modifying a .htaccess file.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Note you can change your configuration by yourself and then restart Piwigo.';
$lang['Try to configure PHP 5'] = 'Try to configure PHP 5.2';
$lang['Sorry!'] = "Sorry!";
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo was not able to configure PHP 5.2';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'You should refer to your hosting provider\'s support and see how you can switch to PHP 5.2 by yourself.';
$lang['Hope to see you back soon.'] = "Hope to see you back soon.";
$lang['Congratulations, Piwigo installation is completed'] = 'Congratulations, Piwigo installation is completed';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning: database.inc.php must only contain what is in the textarea, no line return or space character)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Creation of config file local/config/database.inc.php failed.';
$lang['Download the config file'] = 'Download the config file';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'You can download the config file and upload it to the local/config directory in your installation.';
$lang['Just another Piwigo gallery'] = 'Just another Piwigo gallery';
$lang['Welcome to my photo gallery'] = 'Welcome to my photo gallery';
$lang['Welcome to your new installation of Piwigo!'] = 'Welcome to your new installation of Piwigo!';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Don\'t hesitate to consult our forums for any help: %s';

==> php74-piwigo-15.1.0.tgz: share/piwigo/language/en_UK/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Installation'] = "Installation";
$lang['Basic configuration'] = "Basic configuration";
$lang['Default gallery language'] = "Default gallery language";
$lang['Database configuration'] = "Database configuration";
$lang['Admin configuration'] = "Administration configuration";
$lang['Start Install'] = "Start installation";
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'It will be shown to visitors. It is necessary for website administration';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Connection to server successful, but the connection to the database was not possible.';
$lang['Can\'t connect to server'] = "Cannot connect to server";
$lang['Host'] = "Host";
$lang['localhost or other, supplied by your host provider'] = "localhost or other, supplied by your host provider";
$lang['User'] = "User";
$lang['user login given by your host provider'] = 'user login supplied by your host provider';
$lang['user password given by your host provider'] = 'user password supplied by your host provider';
$lang['Database name'] = "Database name";
$lang['also given by your host provider'] = 'also supplied by your hosting provider';
$lang['Database table prefix'] = "Database tables prefix";
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'database table names will be prefixed with it (enables you to manage your tables better)';
$lang['enter a login for webmaster'] = 'please enter the webmaster username';
$lang['webmaster login can\'t contain characters \' or "'] = 'the webmaster login may not contain the characters \' or "';
$lang['please enter your password again'] = "please enter your password again";
$lang['Keep it confidential, it enables you to access administration panel'] = 'Keep it confidential, it enables you to access the administration panel';
$lang['Password [confirm]'] = "Password [confirm]";
$lang['verification'] = "verification";
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Need help? Ask your question on the <a href="%s">Piwigo message board</a>.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Visitors will be able to use this email to contact the site administrator';
$lang['PHP 5 is required'] = 'PHP 5.3 is required';
$lang['PHP version %s required (you are running on PHP %s)'] = 'PHP version %s required (you are running on PHP %s)';
$lang['It appears your webhost is currently running PHP %s.'] = "It appears your webhost is currently running PHP %s.";
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo may try to switch your configuration to PHP 5.3 by creating or modifying a .htaccess file.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Note you can change your configuration by yourself and then restart Piwigo.';
$lang['Try to configure PHP 5'] = 'Try to configure PHP 5.3';
$lang['Sorry!'] = "Sorry!";
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo was not able to configure PHP 5.3';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'You should refer to your hosting provider\'s support and see how you can switch to PHP 5.3 by yourself.';
$lang['Hope to see you back soon.'] = "Hope to see you back soon.";
$lang['Congratulations, Piwigo installation is completed'] = 'Congratulations, Piwigo installation is completed';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning: database.inc.php must only contain what is in the textarea, no line return or space character)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Creation of config file local/config/database.inc.php failed.';
$lang['Download the config file'] = 'Download the config file';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'You can download the config file and upload it to the local/config directory in your installation.';
$lang['Just another Piwigo gallery'] = 'Just another Piwigo gallery';
$lang['Welcome to my photo gallery'] = 'Welcome to my photo gallery';
$lang['Welcome to your new installation of Piwigo!'] = 'Welcome to your new installation of Piwigo!';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Don\'t hesitate to consult our forums for any help: %s';
